==> mars3d-wind-3.6.8.tgz: package/README.md <==
 
<p align="center">
<img src="//mars3d.cn/logo.png" width="300px" />
</p>

<p align="center">🌎 一款基于WebGL技术实现的三维地球客户端开发平台</p>

<p align="center">
  <a target="_black" href="https://www.npmjs.com/package/mars3d-wind">
    <img alt="Npm version" src="https://img.shields.io/npm/v/mars3d-wind.svg?style=flat&logo=npm&label=版本号" />
  </a>
  <a target="_black" href="https://www.npmjs.com/package/mars3d-wind">
    <img alt="Npm downloads" src="https://img.shields.io/npm/dt/mars3d-wind?style=flat&logo=npm&label=下载量" />
  </a>
  <a target="_black" href="https://github.com/marsgis/mars3d">
    <img alt="GitHub stars" src="https://img.shields.io/github/stars/marsgis/mars3d?style=flat&logo=github" />
  </a>
  <a target="_black" href="https://gitee.com/marsgis/mars3d">
    <img src="https://gitee.com/marsgis/mars3d/badge/star.svg?theme=dark" alt="star" />
  </a>
</p>


Mars3D平台插件, 支持气象 风向图 功能插件
 


## 使用方式
 
使用 Node 环境下的现代 web 前端技术栈时，可以使用 npm 或 cnpm 或 yarn 等方式来安装 mars3d 插件包

```sh
//安装mars3d主库
npm install mars3d --save

//安装mars3d插件（按需安装）
npm install mars3d-wind --save
```
 

安装后在mars3d引入后，引入一次插件即可 

```js 
//导入mars3d主库
import "mars3d/dist/mars3d.css";
import * as mars3d from "mars3d";

//导入mars3d插件 [在mars3d引入后]
import "mars3d-wind";
```

> 关于引入后的具体如何使用，请参考教程[在项目中集成 Mars3D](http://mars3d.cn/dev/guide/start/import.html)中了解更多信息。



## 相关依赖 
 mars3d 
 


## Mars3D 是什么 
>  `Mars3D三维地球平台软件` 是[火星科技](http://marsgis.cn/)研发的一款基于 WebGL 技术实现的三维客户端开发平台，基于[Cesium](https://cesium.com/cesiumjs/)优化提升与B/S架构设计，支持多行业扩展的轻量级高效能GIS开发平台，能够免安装、无插件地在浏览器中高效运行，并可快速接入与使用多种GIS数据和三维模型，呈现三维空间的可视化，完成平台在不同行业的灵活应用。

 > Mars3D平台可用于构建无插件、跨操作系统、 跨浏览器的三维 GIS 应用程序。平台使用 WebGL 来进行硬件加速图形化，跨平台、跨浏览器来实现真正的动态大数据三维可视化。通过 Mars3D产品可快速实现浏览器和移动端上美观、流畅的三维地图呈现与空间分析。

## 相关网站 

- Mars3D官网：[http://mars3d.cn](http://mars3d.cn)  

- Mars3D开源项目列表：[https://github.com/marsgis/mars3d](https://github.com/marsgis/mars3d)


 

## 参考来源
  CanvasWindLayer 参考了: https://blog.csdn.net/axiwang88/article/details/105737114
  
  WindLayer 参考了： https://github.com/RaymanNg/3D-Wind-Field
                    https://github.com/JohnHenryEden/wind3D-custom
  
 

### 如何获取NetCDF文件（.nc）数据
演示数据来自NOAA全球预报系统。原始数据为GRIB2格式，我使用toolsUI将GRIB2文件转换为NetCDF V3文件。
下载数据：https://www.unidata.ucar.edu/software/netcdf/examples/files.html
NOAA全球预报系统：https://www.ncdc.noaa.gov/data-access/model-data/model-datasets/global-forcast-system-gfs

您可以使用NCO（NetCDF运算符）来进一步处理NetCDF数据。我已经编写了一个PowerShell脚本，以通过使用NCO提取和转换数据。

您可以检查“ Util”文件夹以获取详细信息。
https://www.unidata.ucar.edu/software/netcdf-java/v4.5/ToolsUI.html


### Credits
This demo makes use of below repos:
- [CesiumJS](https://github.com/AnalyticalGraphicsInc/cesium)
- [Spector.js](https://github.com/BabylonJS/Spector.js)
- [netcdfjs](https://github.com/cheminfo-js/netcdfjs)
- A good Cesium [tutorial](https://github.com/cesiumlab/cesium-custom-primitive).

==> mars3d-wind-3.10.0.tgz: package/README.md <==
 
<p align="center">
<img src="//mars3d.cn/logo.png" width="300px" />
</p>

<p align="center">🌎 一款基于WebGL技术实现的三维地球客户端开发平台</p>

<p align="center">
  <a target="_black" href="https://www.npmjs.com/package/mars3d-wind">
    <img alt="Npm version" src="https://img.shields.io/npm/v/mars3d-wind.svg?style=flat&logo=npm&label=版本号" />
  </a>
  <a target="_black" href="https://www.npmjs.com/package/mars3d-wind">
    <img alt="Npm downloads" src="https://img.shields.io/npm/dt/mars3d-wind?style=flat&logo=npm&label=下载量" />
  </a>
  <a target="_black" href="https://github.com/marsgis/mars3d">
    <img alt="GitHub stars" src="https://img.shields.io/github/stars/marsgis/mars3d?style=flat&logo=github" />
  </a>
  <a target="_black" href="https://gitee.com/marsgis/mars3d">
    <img src="https://gitee.com/marsgis/mars3d/badge/star.svg?theme=dark" alt="star" />
  </a>
</p>


Mars3D平台插件, 支持气象 风向图 功能插件
 


## 使用方式
 
使用 Node 环境下的现代 web 前端技术栈时，可以使用 npm 或 cnpm 或 yarn 等方式来安装 mars3d 插件包

```sh
//安装mars3d主库(如果已安装请忽略)
npm install mars3d --save

//安装mars3d插件
npm install mars3d-wind --save
```
 

安装后在mars3d引入后，引入一次插件即可 

```js 
//导入mars3d主库
import "mars3d/mars3d.css";
import * as mars3d from "mars3d";

//导入mars3d插件 [在mars3d引入后]
import "mars3d-wind";
```

> 关于引入后的具体如何使用，请参考教程[Mars3D集成到项目](http://mars3d.cn/docs/guide/npm-integration/)中了解更多信息。



## 相关依赖 
 mars3d 
 


## NetCDF文件（.nc）说明
 NetCDF(network Common Data Form)网络通用数据格式是由美国大学大气研究协会（University Corporation for Atmospheric Research，UCAR）的Unidata项目科学家针对科学数据的特点开发的，是一种面向数组型并适于网络共享的数据的描述和编码标准。NetCDF广泛应用于大气科学、水文、海洋学、环境模拟、地球物理等诸多领域。用户可以借助多种方式方便地管理和操作 NetCDF 数据集。

### 如何获取NetCDF数据
- [美国大学大气研究协会 Unidata](https://www.unidata.ucar.edu/software/netcdf/examples/files.html)
- [全球天气预报系统（GFS）](https://www.ncdc.noaa.gov/data-access/model-data/model-datasets/global-forcast-system-gfs)
- [NASA Panoply](https://www.giss.nasa.gov/tools/panoply/)
  
  
### 如何打开NetCDF文件
 nc文件最好为NetCDF version 3形式，文件中必须至少包含U、V速度矩阵。

- [netcdf-java](https://downloads.unidata.ucar.edu/netcdf-java/)


 

## 参考来源
- CanvasWindLayer 参考了: https://blog.csdn.net/axiwang88/article/details/105737114
  
- WindLayer 参考了： https://github.com/RaymanNg/3D-Wind-Field 
                    https://github.com/hongfaqiu/cesium-wind-layer （主要）
  
 

## Mars3D 是什么 
>  `Mars3D三维地球平台软件` 是[火星科技](http://marsgis.cn/)研发的一款基于 WebGL 技术实现的三维客户端开发平台，基于[Cesium](https://cesium.com/cesiumjs/)优化提升与B/S架构设计，支持多行业扩展的轻量级高效能GIS开发平台，能够免安装、无插件地在浏览器中高效运行，并可快速接入与使用多种GIS数据和三维模型，呈现三维空间的可视化，完成平台在不同行业的灵活应用。

 > Mars3D平台可用于构建无插件、跨操作系统、 跨浏览器的三维 GIS 应用程序。平台使用 WebGL 来进行硬件加速图形化，跨平台、跨浏览器来实现真正的动态大数据三维可视化。通过 Mars3D产品可快速实现浏览器和移动端上美观、流畅的三维地图呈现与空间分析。

## 相关网站 

- Mars3D官网：[http://mars3d.cn](http://mars3d.cn)  

- Mars3D开源项目列表：[https://github.com/marsgis/mars3d](https://github.com/marsgis/mars3d)
